==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/tr_tr/support_manager_departments.php <==
<?php
/**
 * Support Manager Departments
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['SupportManagerDepartments.priorities.medium'] = 'Orta';
$lang['SupportManagerDepartments.reminder_intervals.minutes'] = '1$s Dakika';
$lang['SupportManagerDepartments.reminder_intervals.hours'] = '1$s Saat';
$lang['SupportManagerDepartments.reminder_intervals.hour'] = '1 Saat';
$lang['SupportManagerDepartments.ticket_intervals.days'] = '1$s Gün';
$lang['SupportManagerDepartments.ticket_intervals.day'] = '1 Gün';
$lang['SupportManagerDepartments.visibility_options.staff'] = 'Sadece Personel';
$lang['SupportManagerDepartments.visibility_options.client'] = 'Müşteri ve Personel';
$lang['SupportManagerDepartments.field_types.password'] = 'Şifre';
$lang['SupportManagerDepartments.field_types.textarea'] = 'Metin Alanı';
$lang['SupportManagerDepartments.field_types.text'] = 'Metin';
$lang['SupportManagerDepartments.field_types.quantity'] = 'Miktar';
$lang['SupportManagerDepartments.field_types.select'] = 'Açılır';
$lang['SupportManagerDepartments.field_types.radio'] = 'Radyo';
$lang['SupportManagerDepartments.field_types.checkbox'] = 'Onay kutusu';
$lang['SupportManagerDepartments.message_types.deleted'] = 'Silinmiş';
$lang['SupportManagerDepartments.message_types.read'] = 'Okuyun';
$lang['SupportManagerDepartments.security_types.tls'] = 'TLS';
$lang['SupportManagerDepartments.security_types.ssl'] = 'SSL';
$lang['SupportManagerDepartments.security_types.none'] = 'Hiçbiri';
$lang['SupportManagerDepartments.priorities.low'] = 'Düşük';
$lang['SupportManagerDepartments.priorities.high'] = 'Yüksek';
$lang['SupportManagerDepartments.priorities.critical'] = 'Kritik';
$lang['SupportManagerDepartments.priorities.emergency'] = 'Acil Durum';
$lang['SupportManagerDepartments.statuses.visible'] = 'Görünür';
$lang['SupportManagerDepartments.statuses.hidden'] = 'Gizli';
$lang['SupportManagerDepartments.methods.imap'] = 'IMAP';
$lang['SupportManagerDepartments.methods.pop3'] = 'POP3';
$lang['SupportManagerDepartments.methods.pipe'] = 'Boru tesisatı';
$lang['SupportManagerDepartments.methods.none'] = 'Hiçbiri';
$lang['SupportManagerDepartments.!error.department_id.has_tickets'] = 'Departman silinemedi çünkü şu anda kendisine atanmış biletler var.';
$lang['SupportManagerDepartments.!error.auto_delete.format'] = 'Bir destek talebi kapatıldıktan sonra alan verilerinin otomatik olarak silinip silinmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.encrypted.format'] = 'Alan verilerinin şifrelenip şifrelenmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.client_add.format'] = 'İstemcinin ekleme yapmasına izin verilip verilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.type.format'] = 'Lütfen geçerli bir alan türü seçin.';
$lang['SupportManagerDepartments.!error.visibility.format'] = 'Lütfen geçerli bir görünürlük durumu seçin.';
$lang['SupportManagerDepartments.!error.label.empty'] = 'Lütfen bir etiket girin.';
$lang['SupportManagerDepartments.!error.department_id.exists'] = 'Geçersiz departman kimliği.';
$lang['SupportManagerDepartments.!error.status.format'] = 'Geçersiz durum türü.';
$lang['SupportManagerDepartments.!error.response_id.format'] = 'Lütfen geçerli bir otomatik kapama yanıtı seçin.';
$lang['SupportManagerDepartments.!error.max_attachment_size.format'] = 'Maksimum ek boyutu sayısal bir değer olmalıdır.';
$lang['SupportManagerDepartments.!error.attachment_types.length'] = 'Ek türü listesinin uzunluğu 255 karakteri geçemez.';
$lang['SupportManagerDepartments.!error.include_attachments.format'] = 'Bilet eklerinin dahil edilip edilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.reminder_ticket_priority.format'] = 'Lütfen geçerli bir bilet hatırlatma önceliği seçin.';
$lang['SupportManagerDepartments.!error.reminder_ticket_status.format'] = 'Lütfen geçerli bir bilet hatırlatma durumu seçin.';
$lang['SupportManagerDepartments.!error.reminder_ticket_interval.format'] = 'Lütfen geçerli bir hatırlatma bileti aralığı seçin.';
$lang['SupportManagerDepartments.!error.delete_ticket_interval.format'] = 'Lütfen geçerli bir bilet silme aralığı seçin.';
$lang['SupportManagerDepartments.!error.close_ticket_interval.format'] = 'Lütfen geçerli bir yakın bilet aralığı seçin.';
$lang['SupportManagerDepartments.!error.send_ticket_received.format'] = 'Bu departman için bilet onay e-postalarının gönderilip gönderilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.override_from_email.format'] = 'Bu departmanın e-posta adresinin e-posta şablonlarında gelen adresi olarak kullanılmasına izin verilip verilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.require_captcha.format'] = 'İnsan doğrulaması gerekip gerekmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.clients_only.format'] = 'İstemcilerin destek taleplerini açmasına veya yanıtlamasına izin verilip verilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.mark_messages.valid'] = 'POP3 kullanan iletiler yalnızca silindi olarak işaretlenebilir.';
$lang['SupportManagerDepartments.!error.mark_messages.format'] = 'Mesajları işaretlemek için lütfen geçerli bir mesaj türü seçin.';
$lang['SupportManagerDepartments.!error.security.format'] = 'Lütfen geçerli bir güvenlik türü seçin.';
$lang['SupportManagerDepartments.!error.service.format'] = 'Lütfen geçerli bir hizmet türü seçin.';
$lang['SupportManagerDepartments.!error.port.length'] = 'Bağlantı noktasının uzunluğu 6 haneyi geçemez.';
$lang['SupportManagerDepartments.!error.port.format'] = 'Lütfen bir port numarası girin.';
$lang['SupportManagerDepartments.!error.password.format'] = 'Lütfen bir şifre girin.';
$lang['SupportManagerDepartments.!error.user.length'] = 'Kullanıcı adının uzunluğu 64 karakteri geçemez.';
$lang['SupportManagerDepartments.!error.user.format'] = 'Lütfen bir kullanıcı adı girin.';
$lang['SupportManagerDepartments.!error.host.length'] = 'Ana bilgisayar adının uzunluğu 128 karakteri geçemez.';
$lang['SupportManagerDepartments.!error.host.format'] = 'Lütfen geçerli bir ana bilgisayar adı girin.';
$lang['SupportManagerDepartments.!error.default_priority.format'] = 'Geçersiz varsayılan öncelik türü.';
$lang['SupportManagerDepartments.!error.method.mailparse'] = 'E-posta biletlerini ayrıştırmak için PHP Mailparse PECL eklentisi gereklidir.';
$lang['SupportManagerDepartments.!error.method.imap'] = 'POP3 veya IMAP üzerinden ileti indirmek için PHP IMAP eklentisi gereklidir.';
$lang['SupportManagerDepartments.!error.method.format'] = 'Geçersiz yöntem türü.';
$lang['SupportManagerDepartments.!error.email.format'] = 'Lütfen geçerli bir e-posta adresi girin.';
$lang['SupportManagerDepartments.!error.description.empty'] = 'Lütfen bir açıklama girin.';
$lang['SupportManagerDepartments.!error.name.empty'] = 'Lütfen bu departman için bir isim girin.';
$lang['SupportManagerDepartments.!error.company_id.exists'] = 'Geçersiz şirket kimliği.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/tr_tr/support_manager_departments.php <==
<?php
/**
 * Support Manager Departments
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['SupportManagerDepartments.priorities.medium'] = 'Orta';
$lang['SupportManagerDepartments.reminder_intervals.hour'] = '1 Saat';
$lang['SupportManagerDepartments.ticket_intervals.day'] = '1 Gün';
$lang['SupportManagerDepartments.visibility_options.staff'] = 'Sadece Personel';
$lang['SupportManagerDepartments.visibility_options.client'] = 'Müşteri ve Personel';
$lang['SupportManagerDepartments.field_types.password'] = 'Şifre';
$lang['SupportManagerDepartments.field_types.textarea'] = 'Metin Alanı';
$lang['SupportManagerDepartments.field_types.text'] = 'Metin';
$lang['SupportManagerDepartments.field_types.quantity'] = 'Miktar';
$lang['SupportManagerDepartments.field_types.select'] = 'Açılır';
$lang['SupportManagerDepartments.field_types.radio'] = 'Radyo';
$lang['SupportManagerDepartments.field_types.checkbox'] = 'Onay kutusu';
$lang['SupportManagerDepartments.message_types.deleted'] = 'Silinmiş';
$lang['SupportManagerDepartments.message_types.read'] = 'Okuyun';
$lang['SupportManagerDepartments.security_types.tls'] = 'TLS';
$lang['SupportManagerDepartments.security_types.ssl'] = 'SSL';
$lang['SupportManagerDepartments.security_types.none'] = 'Hiçbiri';
$lang['SupportManagerDepartments.priorities.low'] = 'Düşük';
$lang['SupportManagerDepartments.priorities.high'] = 'Yüksek';
$lang['SupportManagerDepartments.priorities.critical'] = 'Kritik';
$lang['SupportManagerDepartments.priorities.emergency'] = 'Acil Durum';
$lang['SupportManagerDepartments.statuses.visible'] = 'Görünür';
$lang['SupportManagerDepartments.statuses.hidden'] = 'Gizli';
$lang['SupportManagerDepartments.methods.imap'] = 'IMAP';
$lang['SupportManagerDepartments.methods.pop3'] = 'POP3';
$lang['SupportManagerDepartments.methods.pipe'] = 'Boru tesisatı';
$lang['SupportManagerDepartments.methods.none'] = 'Hiçbiri';
$lang['SupportManagerDepartments.!error.department_id.has_tickets'] = 'Departman silinemedi çünkü şu anda kendisine atanmış biletler var.';
$lang['SupportManagerDepartments.!error.auto_delete.format'] = 'Bir destek talebi kapatıldıktan sonra alan verilerinin otomatik olarak silinip silinmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.encrypted.format'] = 'Alan verilerinin şifrelenip şifrelenmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.client_add.format'] = 'İstemcinin ekleme yapmasına izin verilip verilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.type.format'] = 'Lütfen geçerli bir alan türü seçin.';
$lang['SupportManagerDepartments.!error.visibility.format'] = 'Lütfen geçerli bir görünürlük durumu seçin.';
$lang['SupportManagerDepartments.!error.label.empty'] = 'Lütfen bir etiket girin.';
$lang['SupportManagerDepartments.!error.department_id.exists'] = 'Geçersiz departman kimliği.';
$lang['SupportManagerDepartments.!error.status.format'] = 'Geçersiz durum türü.';
$lang['SupportManagerDepartments.!error.response_id.format'] = 'Lütfen geçerli bir otomatik kapama yanıtı seçin.';
$lang['SupportManagerDepartments.!error.max_attachment_size.format'] = 'Maksimum ek boyutu sayısal bir değer olmalıdır.';
$lang['SupportManagerDepartments.!error.attachment_types.length'] = 'Ek türü listesinin uzunluğu 255 karakteri geçemez.';
$lang['SupportManagerDepartments.!error.include_attachments.format'] = 'Bilet eklerinin dahil edilip edilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.reminder_ticket_priority.format'] = 'Lütfen geçerli bir bilet hatırlatma önceliği seçin.';
$lang['SupportManagerDepartments.!error.reminder_ticket_status.format'] = 'Lütfen geçerli bir bilet hatırlatma durumu seçin.';
$lang['SupportManagerDepartments.!error.reminder_ticket_interval.format'] = 'Lütfen geçerli bir hatırlatma bileti aralığı seçin.';
$lang['SupportManagerDepartments.!error.delete_ticket_interval.format'] = 'Lütfen geçerli bir bilet silme aralığı seçin.';
$lang['SupportManagerDepartments.!error.close_ticket_interval.format'] = 'Lütfen geçerli bir yakın bilet aralığı seçin.';
$lang['SupportManagerDepartments.!error.send_ticket_received.format'] = 'Bu departman için bilet onay e-postalarının gönderilip gönderilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.override_from_email.format'] = 'Bu departmanın e-posta adresinin e-posta şablonlarında gelen adresi olarak kullanılmasına izin verilip verilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.require_captcha.format'] = 'İnsan doğrulaması gerekip gerekmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.clients_only.format'] = 'İstemcilerin destek taleplerini açmasına veya yanıtlamasına izin verilip verilmeyeceği 0 veya 1 olarak ayarlanmalıdır.';
$lang['SupportManagerDepartments.!error.mark_messages.valid'] = 'POP3 kullanan iletiler yalnızca silindi olarak işaretlenebilir.';
$lang['SupportManagerDepartments.!error.mark_messages.format'] = 'Mesajları işaretlemek için lütfen geçerli bir mesaj türü seçin.';
$lang['SupportManagerDepartments.!error.security.format'] = 'Lütfen geçerli bir güvenlik türü seçin.';
$lang['SupportManagerDepartments.!error.service.format'] = 'Lütfen geçerli bir hizmet türü seçin.';
$lang['SupportManagerDepartments.!error.port.length'] = 'Bağlantı noktasının uzunluğu 6 haneyi geçemez.';
$lang['SupportManagerDepartments.!error.port.format'] = 'Lütfen bir port numarası girin.';
$lang['SupportManagerDepartments.!error.password.format'] = 'Lütfen bir şifre girin.';
$lang['SupportManagerDepartments.!error.user.length'] = 'Kullanıcı adının uzunluğu 64 karakteri geçemez.';
$lang['SupportManagerDepartments.!error.user.format'] = 'Lütfen bir kullanıcı adı girin.';
$lang['SupportManagerDepartments.!error.host.length'] = 'Ana bilgisayar adının uzunluğu 128 karakteri geçemez.';
$lang['SupportManagerDepartments.!error.host.format'] = 'Lütfen geçerli bir ana bilgisayar adı girin.';
$lang['SupportManagerDepartments.!error.default_priority.format'] = 'Geçersiz varsayılan öncelik türü.';
$lang['SupportManagerDepartments.!error.method.mailparse'] = 'E-posta biletlerini ayrıştırmak için PHP Mailparse PECL eklentisi gereklidir.';
$lang['SupportManagerDepartments.!error.method.imap'] = 'POP3 veya IMAP üzerinden ileti indirmek için PHP IMAP eklentisi gereklidir.';
$lang['SupportManagerDepartments.!error.method.format'] = 'Geçersiz yöntem türü.';
$lang['SupportManagerDepartments.!error.email.format'] = 'Lütfen geçerli bir e-posta adresi girin.';
$lang['SupportManagerDepartments.!error.description.empty'] = 'Lütfen bir açıklama girin.';
$lang['SupportManagerDepartments.!error.name.empty'] = 'Lütfen bu departman için bir isim girin.';
$lang['SupportManagerDepartments.!error.company_id.exists'] = 'Geçersiz şirket kimliği.';
$lang['SupportManagerDepartments.reminder_intervals.hours'] = '%1$s Saatler';
$lang['SupportManagerDepartments.reminder_intervals.minutes'] = '%1$s Dakika';
$lang['SupportManagerDepartments.ticket_intervals.days'] = '%1$s Günler';
$lang['SupportManagerDepartments.!error.priorities[].format'] = 'Bir veya daha fazla öncelik geçersiz.';
$lang['SupportManagerDepartments.!error.priorities[].empty'] = 'En az bir öncelik seçin.';
